aerosoltools.aerosol2d.Aerosol2D.plot_psd — aerosoltools 0.1.0 documentation

# aerosoltools.aerosol2d.Aerosol2D.plot_psd

Aerosol2D.plot_psd(activities=None, normalize=True, ax=None)

  Plot the average particle size distribution (PSD) for the entire dataset and optionally selected activities.

  ## Parameters

  activitieslist of str, optional

    List of activity names to include. If None, all defined activities are plotted.

  normalizebool, optional

    Whether to normalize PSD to dlogDp before plotting. If data is already normalized, will respect that.

  axmatplotlib.axes.Axes, optional

    Optional matplotlib Axes object to plot on.

  ## Returns

  figmatplotlib.figure.Figure

    The matplotlib Figure object.

  axmatplotlib.axes.Axes

    The matplotlib Axes object.

  Parameters:

    - activities (list[str] | None)

    - normalize (bool)